Improve this Doc View Source
Deprecated:

In an effort to keep synchronized with router changes in Angular 2, this implementation of the Component Router (ngComponentRouter module) has been deprecated and will not receive further updates. We are investigating backporting the Angular 2 Router to Angular 1, but alternatively, use the `ngRoute` module or community developed projects (e.g. ui-router).

This type extends the `Router`.

Apart from the Top Level Component (`$routerRootComponent`) which is associated with the `$rootRouter`, every Routing Component is associated with a `ChildRouter`, which manages the routing for that Routing Component.